@@ -1,7 +1,7 @@
 package Data::Sah::Compiler::Prog;
 
-our $DATE = '2015-10-18'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010;
 use strict;
@@ -679,8 +679,8 @@ sub before_clause {
 
     if ($cd->{args}{debug}) {
         state $json = do {
-            require JSON;
-            JSON->new->allow_nonref;
+            require JSON::MaybeXS;
+            JSON::MaybeXS->new->allow_nonref;
         };
         my $clset = $cd->{clset};
         my $cl    = $cd->{clause};
@@ -770,7 +770,7 @@ Data::Sah::Compiler::Prog - Base class for programming language compilers
 
 =head1 VERSION
 
-This document describes version 0.74 of Data::Sah::Compiler::Prog (from Perl distribution Data-Sah), released on 2015-10-18.
+This document describes version 0.75 of Data::Sah::Compiler::Prog (from Perl distribution Data-Sah), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -843,6 +843,38 @@ loading of modules, etc.
 Note: Current assumptions/hard-coded things for the supported languages: ternary
 operator (C<? :>), semicolon as statement separator.
 
+=head1 INTERNAL VARIABLES IN THE GENERATED CODE
+
+The generated code maintains the following variables. C<_sahv_> prefix stands
+for "Sah validator", it is used to minimize clash with data_term.
+
+=over
+
+=item * _sahv_dpath => ARRAY
+
+Analogous to C<spath> in compilation data, this variable stands for "data path"
+and is used to track location within data. If a clause is checking each element
+of an array (like the 'each_elem' or 'elems' array clause), this variable will
+be adjusted accordingly. Error messages thus can be more informative by pointing
+more exactly where in the data the problem lies.
+
+=item * C<tmp_data_term> => ANY
+
+As explained in the C<compile()> method, this is used to store temporary value
+when checking against clauses.
+
+=item * _sahv_stack => ARRAY
+
+This variable is used to store validation result of subdata. It is only used if
+the validator is returning a string or full structure, not a single boolean
+value. See C<Data::Sah::Compiler::js::TH::hash> for an example.
+
+=item * _sahv_x
+
+Usually used as temporary variable in short, anonymous functions.
+
+=back
+
 =head1 ATTRIBUTES
 
 These usually need not be set/changed by users.
@@ -1036,38 +1068,6 @@ Generate a comment. For example, in perl compiler:
 
 Will return an empty string if compile argument C<comment> is set to false.
 
-=head1 INTERNAL VARIABLES IN THE GENERATED CODE
-
-The generated code maintains the following variables. C<_sahv_> prefix stands
-for "Sah validator", it is used to minimize clash with data_term.
-
-=over
-
-=item * _sahv_dpath => ARRAY
-
-Analogous to C<spath> in compilation data, this variable stands for "data path"
-and is used to track location within data. If a clause is checking each element
-of an array (like the 'each_elem' or 'elems' array clause), this variable will
-be adjusted accordingly. Error messages thus can be more informative by pointing
-more exactly where in the data the problem lies.
-
-=item * C<tmp_data_term> => ANY
-
-As explained in the C<compile()> method, this is used to store temporary value
-when checking against clauses.
-
-=item * _sahv_stack => ARRAY
-
-This variable is used to store validation result of subdata. It is only used if
-the validator is returning a string or full structure, not a single boolean
-value. See C<Data::Sah::Compiler::js::TH::hash> for an example.
-
-=item * _sahv_x
-
-Usually used as temporary variable in short, anonymous functions.
-
-=back
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.
@@ -1090,7 +1090,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
