@@ -1,7 +1,7 @@
 package Data::Sah::Compiler::js;
 
-our $DATE = '2015-10-18'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010;
 use strict;
@@ -33,8 +33,8 @@ sub literal {
     my ($self, $val) = @_;
 
     state $json = do {
-        require JSON;
-        JSON->new->allow_nonref;
+        require JSON::MaybeXS;
+        JSON::MaybeXS->new->allow_nonref;
     };
 
     # we need cleaning since json can't handle qr//, for one.
@@ -263,7 +263,7 @@ Data::Sah::Compiler::js - Compile Sah schema to JavaScript code
 
 =head1 VERSION
 
-This document describes version 0.74 of Data::Sah::Compiler::js (from Perl distribution Data-Sah), released on 2015-10-18.
+This document describes version 0.75 of Data::Sah::Compiler::js (from Perl distribution Data-Sah), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -275,18 +275,6 @@ Derived from L<Data::Sah::Compiler::Prog>.
 
 =for Pod::Coverage BUILD ^(after_.+|before_.+|name|expr|true|false|literal|expr_.+|stmt_.+|block_uses_sub)$
 
-=head1 METHODS
-
-=head2 new() => OBJ
-
-=head2 $c->compile(%args) => RESULT
-
-Aside from Prog's arguments, this class supports these arguments:
-
-=over
-
-=back
-
 =head1 DEVELOPER NOTES
 
 To generate expression code that says "all subexpression must be true", you can
@@ -300,6 +288,18 @@ To say "at least one subexpression must be true":
 
  !ARRAY.every(function(x) { return !blah(x) })
 
+=head1 METHODS
+
+=head2 new() => OBJ
+
+=head2 $c->compile(%args) => RESULT
+
+Aside from Prog's arguments, this class supports these arguments:
+
+=over
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.
@@ -322,7 +322,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
