@@ -1,7 +1,7 @@
 package Data::Sah::JS;
 
-our $DATE = '2015-10-18'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010;
 use strict;
@@ -58,12 +58,12 @@ sub gen_validator {
 
     sub {
         require File::Temp;
-        require JSON;
+        require JSON::MaybeXS;
         #require String::ShellQuote;
 
         my $data = shift;
 
-        state $json = JSON->new->allow_nonref;
+        state $json = JSON::MaybeXS->new->allow_nonref;
 
         # code to be sent to nodejs
         my $src = "var validator = $v_src;\n\n".
@@ -95,7 +95,7 @@ Data::Sah::JS - Some functions to use JavaScript Sah validator code from Perl
 
 =head1 VERSION
 
-This document describes version 0.74 of Data::Sah::JS (from Perl distribution Data-Sah), released on 2015-10-18.
+This document describes version 0.75 of Data::Sah::JS (from Perl distribution Data-Sah), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -148,10 +148,6 @@ log validator source code).
 
 L<LOG_SAH_VALIDATOR_CODE>
 
-=head1 SEE ALSO
-
-L<Data::Sah>, L<Data::Sah::Compiler::js>.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.
@@ -168,13 +164,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Data::Sah>, L<Data::Sah::Compiler::js>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
