@@ -10,16 +10,16 @@ use Data::Sah::JS qw();
 use File::chdir;
 use File::ShareDir ();
 use File::ShareDir::Tarball ();
-use File::Slurp::Tiny qw(read_file);
+use File::Slurper qw(read_text);
 use File::Temp qw(tempfile tempdir);
-use JSON;
+use JSON::MaybeXS;
 use List::Util qw(first);
 use String::Indent qw(indent);
 use Test::Exception;
 use Test::More 0.98;
 use Version::Util qw(version_eq);
 
-my $json = JSON->new->allow_nonref;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 my $sah = Data::Sah->new;
 
@@ -132,7 +132,7 @@ sub run_spectest {
             next;
         }
         subtest $file => sub {
-            my $tspec = $json->decode(~~read_file("$dir/spectest/$file"));
+            my $tspec = $json->decode(~~read_text("$dir/spectest/$file"));
             for my $test (@{ $tspec->{tests} }) {
                 subtest $test->{name} => sub {
                     if (my $reason = $should_skip_test->($test)) {
@@ -162,7 +162,7 @@ sub run_spectest {
             next;
         }
         subtest $file => sub {
-            my $tspec = $json->decode(~~read_file("$dir/spectest/$file"));
+            my $tspec = $json->decode(~~read_text("$dir/spectest/$file"));
             for my $test (@{ $tspec->{tests} }) {
                 subtest $test->{name} => sub {
                     if (my $reason = $should_skip_test->($test)) {
@@ -195,7 +195,7 @@ sub run_spectest {
         }
         subtest $file => sub {
             diag "Loading $file ...";
-            my $tspec = $json->decode(~~read_file("$dir/spectest/$file"));
+            my $tspec = $json->decode(~~read_text("$dir/spectest/$file"));
             note "Test version: ", $tspec->{version};
             my $tests = $tspec->{tests};
             if ($cname eq 'perl') {
